==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/admin/user_titles.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright © 2008 MyBB Group, All Rights Reserved
 * 
 * $Id: user_titles.lang.php 4304 2009-01-02 01:11:56Z chris $
 */

$l['user_titles'] = "User Titles";
$l['user_titles_desc'] = "This section allows management of user titles. User titles are assigned to users based on the number of posts they make and also allow a custom 'Star' image to be shown based on the number of posts the user has.";
$l['add_new_user_title'] = "Add New User Title";
$l['add_new_user_title_desc'] = "This section allows you to add a new user title. <i>Note: This is <strong>not</strong> the <u><a href=\"index.php?module=user/group_promotions\">promotion system.</a></u></i>";

$l['error_missing_title'] = "You did not enter a title for this user title";
$l['error_missing_posts'] = "You did not enter the minimum number of posts for this user title";
$l['error_invalid_user_title'] = "You have specified an invalid user title";

$l['success_user_title_created'] = "The new user title has been created successfully.";
$l['success_user_title_updated'] = "The user title has been updated successfully.";
$l['success_user_title_deleted'] = "The specified user title has been deleted successfully.";

$l['title_to_assign'] = "Title to Assign";
$l['title_to_assign_desc'] = "This title will be shown for users underneath their name if they do not have a custom title set.";
$l['minimum_posts'] = "Minimum Posts";
$l['minimum_posts_desc'] = "The minimum number of posts for a user to have before they're assigned this user title.";
$l['number_of_stars'] = "Number of Stars";
$l['number_of_stars_desc'] = "Enter the number of stars to be shown under this user title. Set to 0 to show no stars.";
$l['star_image'] = "Star Image";
$l['star_image_desc'] = "If this user title should show stars, enter the path to the star image here. If empty, the user group star image will be shown. Use {theme} to specify the image directory for the viewers current theme.";
$l['save_user_title'] = "Save User Title";
$l['edit_user_title'] = "Edit User Title";
$l['edit_user_title_desc'] = "This section allows you to edit a user title.";
$l['user_title_deletion_confirmation'] = "Are you sure you want to delete this user title?";
$l['manage_user_titles'] = "Manage User Titles";
$l['user_title'] = "User Title";
$l['no_user_titles'] = "You do not have any user titles defined at the moment";

?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/admin/user_titles.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 * 
 * $Id: user_titles.lang.php 5349 2011-02-14 23:51:52Z MattR $
 */

$l['user_titles'] = "User Titles";
$l['user_titles_desc'] = "This section allows management of user titles. User titles are assigned to users based on the number of posts they make and also allow a custom 'Star' image to be shown based on the number of posts the user has.";
$l['add_new_user_title'] = "Add New User Title";
$l['add_new_user_title_desc'] = "This section allows you to add a new user title. <i>Note: This is <strong>not</strong> the <u><a href=\"index.php?module=user-group_promotions\">promotion system.</a></u></i>";

$l['error_missing_title'] = "You did not enter a title for this user title";
$l['error_missing_posts'] = "You did not enter the minimum number of posts for this user title";
$l['error_invalid_user_title'] = "You have specified an invalid user title";

$l['success_user_title_created'] = "The new user title has been created successfully.";
$l['success_user_title_updated'] = "The user title has been updated successfully.";
$l['success_user_title_deleted'] = "The specified user title has been deleted successfully.";

$l['title_to_assign'] = "Title to Assign";
$l['title_to_assign_desc'] = "This title will be shown for users underneath their name if they do not have a custom title set.";
$l['minimum_posts'] = "Minimum Posts";
$l['minimum_posts_desc'] = "The minimum number of posts for a user to have before they're assigned this user title.";
$l['number_of_stars'] = "Number of Stars";
$l['number_of_stars_desc'] = "Enter the number of stars to be shown under this user title. Set to 0 to show no stars.";
$l['star_image'] = "Star Image";
$l['star_image_desc'] = "If this user title should show stars, enter the path to the star image here. If empty, the user group star image will be shown. Use {theme} to specify the image directory for the viewers current theme.";
$l['save_user_title'] = "Save User Title";
$l['edit_user_title'] = "Edit User Title";
$l['edit_user_title_desc'] = "This section allows you to edit a user title.";
$l['user_title_deletion_confirmation'] = "Are you sure you want to delete this user title?";
$l['manage_user_titles'] = "Manage User Titles";
$l['user_title'] = "User Title";
$l['no_user_titles'] = "You do not have any user titles defined at the moment";

?>
